@@ -5,12 +5,7 @@
 #  open source, and has the attribution requirements (GPL Section 7) in
 #    http://statnetproject.org/attribution
 #
-# Copyright 2003 Mark S. Handcock, University of Washington
-#                David R. Hunter, Penn State University
-#                Carter T. Butts, University of California - Irvine
-#                Steven M. Goodreau, University of Washington
-#                Martina Morris, University of Washington
-# Copyright 2007 The statnet Development Team
+#  Copyright 2010 the statnet development team
 ######################################################################
     gof <- function(object, ...){
       UseMethod("gof")
@@ -110,7 +105,7 @@ gof.formula <- function(formula, ..., theta0=NULL, nsim=100,
   }
 
 # if(is.bipartite(nw)){
-#   formula <- safeupdate.formula(formula, ~ . + bipartite)
+#   formula <- ergm.update.formula(formula, ~ . + bipartite)
 #   trms <- ergm.getterms(formula)
 #   termnames <- ergm.gettermnames(trms)
 # }
@@ -307,7 +302,7 @@ gof.formula <- function(formula, ..., theta0=NULL, nsim=100,
 #     if ((i %% 10 == 0) || (i==nsim)) cat("\n")
 #    }
     if ('model' %in% all.gof.vars) {
-     sim.model[i,] <- summary(safeupdate.formula(formula,tempnet ~ .))
+     sim.model[i,] <- summary(ergm.update.formula(formula,tempnet ~ .))
     }
     if ('distance' %in% all.gof.vars) {
      sim.dist[i,] <- ergm.geodistdist(tempnet)
@@ -1116,6 +1111,6 @@ plot.gofobject <- function(x, ...,
 #}
 
 ergm.rhs.formula <- function(formula){
-#all.vars(safeupdate.formula(formula, .~0)) 
+#all.vars(ergm.update.formula(formula, .~0)) 
  unlist(dimnames(attr(terms(formula),"factors"))[-1])
 }
