@@ -1,4 +1,13 @@
-network.update<-function(nw,newmatrix,matrix.type=NULL)
+#  File ergm/R/network.update.R
+#  Part of the statnet package, http://statnetproject.org
+#
+#  This software is distributed under the GPL-3 license.  It is free,
+#  open source, and has the attribution requirements (GPL Section 7) in
+#    http://statnetproject.org/attribution
+#
+#  Copyright 2010 the statnet development team
+######################################################################
+network.update<-function(nw,newmatrix,matrix.type=NULL,output="network")
 {
 #  print(paste("old:",network.edgecount(nw)," new:", nrow(newmatrix),collapse=" "))
   unw <- network.copy(nw)
