@@ -1,3 +1,13 @@
+/*
+ *  File ergm/src/wtedgetree.c
+ *  Part of the statnet package, http://statnetproject.org
+ *
+ *  This software is distributed under the GPL-3 license.  It is free,
+ *  open source, and has the attribution requirements (GPL Section 7) in
+ *    http://statnetproject.org/attribution
+ *
+ *  Copyright 2010 the statnet development team
+ */
 #include "wtedgetree.h"
 
 /*######################################################################
@@ -71,6 +81,7 @@ WtNetwork WtNetworkInitialize(Vertex *heads, Vertex *tails, double *weights,
     else 
       WtAddEdgeToTrees(h,t,w,&nw);
   }
+  PutRNGstate();
   return nw;
 }
 
